<?php
class appHrefLangFrontendComponents extends sfComponents
{
    public function executeHrefLang()
    {   
        $this->config = stConfig::getInstance(sfContext::getInstance(), 'appHrefLangBackend');

        if ($this->config->get('enable', null, true) != 1)
        {
            return sfView::NONE;
        }

        $languages = LanguagePeer::doSelectActive();

        if (!$languages || count($languages) == 1)
        {
            return sfView::NONE;
        }
        
        $active_cultures = $this->getActiveLanguages($languages);

        // home page
        $this->makeHrefsHomePage($active_cultures);

        // product
        $this->makeHrefsProduct($active_cultures);
        
        // category
        $this->makeHrefsCategory($active_cultures);

        // producer
        $this->makeHrefsProducer($active_cultures);

        // product group
        $this->makeHrefsProductGroup($active_cultures);

        // infromation page
        $this->makeHrefsWebpage($active_cultures);

        return sfView::NONE;
    }

    public function makeHrefsHomePage($active_cultures)
    {

        $place = array('action' => 'index', 'module' => 'stFrontendMain'); 

        if ((sfContext::getInstance()->getActionName()==$place['action']) && (sfContext::getInstance()->getModuleName()==$place['module'])){

            $this->addHrefs($active_cultures, array('action' => $place['action'], 'module' => $place['module']));
        }

    }

    public function makeHrefsProduct($active_cultures)
    {
        $place = array('action' => 'show', 'module' => 'stProduct');

         if ((sfContext::getInstance()->getActionName()==$place['action']) && (sfContext::getInstance()->getModuleName()==$place['module'])){
            
            $product = $this->getContext()->getActionStack()->getLastEntry()->getActionInstance()->product;

            if($product){

                $c = new Criteria();
                
                $c->add(ProductI18nPeer::ID, $product->getId());
                
                $products_i18n = ProductI18nPeer::doSelect($c);

                foreach ($products_i18n as $product_i18n){

                    $urls[$this->getIsoShortcut($product_i18n->getCulture())] = $product_i18n->getUrl();

                }

                $urls = $this->makeUrls($active_cultures, $urls, $product->getOptUrl());

                $this->addHrefs($active_cultures, $place['module'].'/'.$place['action'].'?url=', $urls);
            }
         }

    }

    public function makeHrefsCategory($active_cultures)
    {

        $place = array('action' => 'list', 'module' => 'stProduct');

         if ((sfContext::getInstance()->getActionName()==$place['action']) && (sfContext::getInstance()->getModuleName()==$place['module'])){
            
            $category = $this->getContext()->getActionStack()->getLastEntry()->getActionInstance()->category;

               if($category){

                $c = new Criteria();
                    
                $c->add(CategoryI18nPeer::ID, $category->getId());
                    
                $categories_i18n = CategoryI18nPeer::doSelect($c);

                $add_page = $this->getPage(sfContext::getInstance()->getActionStack()->getLastEntry()->getActionInstance());

                foreach ($categories_i18n as $category_i18n){

                        if($category_i18n->getUrl()){

                            $urls[$this->getIsoShortcut($category_i18n->getCulture())] = $category_i18n->getUrl().$add_page;
    
                        }
                    }
                
                $urls = $this->makeUrls($active_cultures, $urls, $category->getOptUrl());

                $this->addHrefs($active_cultures, $place['module'].'/'.$place['action'].'?url=', $urls);
        
          }  

    }

    }

    public function makeHrefsProducer($active_cultures)
    {

        $place = array('action' => 'producerList', 'module' => 'stProduct');

         if ((sfContext::getInstance()->getActionName()==$place['action']) && (sfContext::getInstance()->getModuleName()==$place['module'])){
            
            $producer = $this->getContext()->getActionStack()->getLastEntry()->getActionInstance()->producer;

            if($producer){

                $c = new Criteria();
                
                $c->add(ProducerI18nPeer::ID, $producer->getId());
                
                $producers_i18n = ProducerI18nPeer::doSelect($c);

                $add_page = $this->getPage(sfContext::getInstance()->getActionStack()->getLastEntry()->getActionInstance());

                foreach ($producers_i18n as $producer_i18n){

                    $urls[$this->getIsoShortcut($producer_i18n->getCulture())] = $producer_i18n->getUrl().$add_page;
                }
                
                $urls = $this->makeUrls($active_cultures, $urls, $producer->getOptUrl());

                $this->addHrefs($active_cultures, $place['module'].'/'.$place['action'].'?url=', $urls);

            }

          }  

    }

    public function makeHrefsProductGroup($active_cultures)
    {
        $place = array('action' => 'groupList', 'module' => 'stProduct');

         if ((sfContext::getInstance()->getActionName()==$place['action']) && (sfContext::getInstance()->getModuleName()==$place['module'])){
            
            $product_group = $this->getContext()->getActionStack()->getLastEntry()->getActionInstance()->product_group;

               if($product_group){

                $c = new Criteria();
                    
                $c->add(ProductGroupI18nPeer::ID, $product_group->getId());
                    
                $product_groups_i18n = ProductGroupI18nPeer::doSelect($c);

                $add_page = $this->getPage(sfContext::getInstance()->getActionStack()->getLastEntry()->getActionInstance());

                    foreach ($product_groups_i18n as $product_group_i18n){

                        if($product_group_i18n->getUrl()){

                            $urls[$this->getIsoShortcut($product_group_i18n->getCulture())] = $product_group_i18n->getUrl().$add_page;

                        }
                    }
                
                $urls = $this->makeUrls($active_cultures, $urls, $product_group->getOptUrl());

                $this->addHrefs($active_cultures, $place['module'].'/'.$place['action'].'?url=', $urls);

                }
          }  

    }


    public function makeHrefsWebpage($active_cultures)
    {

        $place = array('action' => 'index', 'module' => 'stWebpageFrontend');

         if ((sfContext::getInstance()->getActionName()==$place['action']) && (sfContext::getInstance()->getModuleName()==$place['module'])){
            
            $webpage = $this->getContext()->getActionStack()->getLastEntry()->getActionInstance()->webpage;

               if($webpage){

                $c = new Criteria();
                    
                $c->add(WebpageI18nPeer::ID, $webpage->getId());
                    
                $webpages_i18n = WebpageI18nPeer::doSelect($c);

                    foreach ($webpages_i18n as $webpage_i18n){

                        if($webpage_i18n->getUrl()){

                            $urls[$this->getIsoShortcut($webpage_i18n->getCulture())] = $webpage_i18n->getUrl();

                        }
                    }
                
                $urls = $this->makeUrls($active_cultures, $urls, $webpage->getOptUrl());

                $this->addHrefs($active_cultures, $place['module'].'/'.$place['action'].'?url=', $urls);

                }
          }  

    }


    public function addHrefs($active_cultures, $uri, $i18n = false)
    {
            if (is_array($i18n)){

                foreach ($i18n as $for_lang => $url){

                $hrefs[$for_lang] = st_url_for($uri.$i18n[$for_lang], true, null, null, $for_lang);

                }

            }else{

                foreach ($active_cultures as $for_lang){

                $hrefs[$for_lang] = st_url_for($uri, true, null, null, $for_lang);

                }
            }

        echo " 
        ";   
        foreach ($hrefs as $lang => $href) {
        echo '<link rel="alternate" hreflang="'.$lang.'" href="'.$href.'">
        ';
        }
   
    }

    public function getActiveLanguages($languages){

        foreach ($languages as $language) {          
                $active_cultures[] = $language->getLanguage();
        }

    return $active_cultures;

    } 

    public function makeUrls($active_cultures, $urls, $opt_url){
            
        foreach ($active_cultures as $iso){
               
               $real_urls[$iso] = $urls[$iso] ?? $opt_url;
        }

        return $real_urls;

    }

    public function getCultureShortcut($v)
    {
        if ($v == 'pl')
        {
            $v = 'pl_PL';
        } elseif ($v == 'en')
        {
            $v = 'en_US';
        }

        return $v;
    }
        

        public function getIsoShortcut($v)
    {
        if ($v == 'pl_PL')
        {
            $v = 'pl';
        } elseif ($v == 'en_US'){
            $v = 'en';
        }

        return $v;
    }

    private function getPage($action_instance){

        $page = '';

        if ($action_instance->hasRequestParameter('page')){
                    
            $page = $action_instance->getRequestParameter('page');
                
        }

        $add_page = '';

        if($page > 1){

            $add_page = $page;
         
        return "/".$add_page;

        }else{

            return '';
        }

        

    }

}